<?php

/*
 * @package RS-MINI
 * @copyright (c) 2015 Alexey Glumov aka Rio-Shaman (support@rio-shaman.ru)
 * @license GNU General Public License version 2; see LICENSE.txt
 *
 */
 

namespace core;


if(!defined('RS-MINI')) die();


/*
 * request v 1.0
 * 
 * Класс получает данные из глобальных массивов и обрабатывает их
 *
 */

class request
{   
    
    /*
     * хранит значение полученное методами getHttpPost(), getHttpGet(), getHttpRequest(), getHttpFiles(), getHttpCookie()
     *
     * @var    - string
     * @access - private
     */
    
    private $httpData = NULL;
    
    /*
     * получаем данные из глобавльного массива $_SESSION
     * 
     * @access - public
     * @return - сам себя
     * 
     * @param string name - ключ элемента массива
     */
     
    public function getHttpSession($name)
    {
        $this->httpData = (isset($_SESSION[$name])) ? $_SESSION[$name] : NULL;
        return $this;
    }
    
    /*
     * получаем данные из глобавльного массива $_COOKIE
     * 
     * @access - public
     * @return - сам себя
     * 
     * @param string name - ключ элемента массива
     */
     
    public function getHttpCookie($name)
    {
        $this->httpData = (isset($_COOKIE[$name])) ? $_COOKIE[$name] : NULL;
        return $this;
    }
    
    /*
     * получаем данные из глобавльного массива $_POST
     * 
     * @access - public
     * @return - сам себя
     * 
     * @param string name - ключ элемента массива
     */
     
    public function getHttpPost($name)
    {
        $this->httpData = (isset($_POST[$name])) ? $_POST[$name] : NULL;
        return $this;
    }
    
    /*
     * получаем данные из глобавльного массива $_GET
     * 
     * @access - public
     * @return - сам себя
     * 
     * @param string name - ключ элемента массива
     */
    
    public function getHttpGet($name)
    {
        $this->httpData = (isset($_GET[$name])) ? $_GET[$name] : NULL;
        return $this;
    }
    
    /*
     * получаем данные из глобавльного массива $_REQUEST
     * 
     * @access - public
     * @return - сам себя
     * 
     * @param string name - ключ элемента массива
     */
    
    public function getHttpRequest($name)
    {
        $this->httpData = (isset($_REQUEST[$name])) ? $_REQUEST[$name] : NULL;
        return $this;
    }
    
    /*
     * получаем данные из глобавльного массива $_FILES
     * 
     * @access - public
     * @return - сам себя
     * 
     * @param string name - ключ элемента массива
     */
    
    public function getHttpFiles($name)
    {
        $this->httpData = (isset($_FILES[$name])) ? $_FILES[$name] : NULL;
        return $this;
    }
    
    /*
     * получаем данные из глобавльного массива $_SERVER. В основном метод написан для получение HTTP_HOST и REQUEST_URI ключей
     * 
     * @access - public
     * @return - сам себя
     * 
     * @param string name - ключ элемента массива
     */
    
    public function getHttpServer($name)
    {
        $this->httpData = (isset($_SERVER[$name])) ? $_SERVER[$name] : NULL;
        return $this;
    }
    
    /*
     * обрабатывает данные в свойстве $this->httpData как стороку
     * 
     * @access - public
     * @return - обработанные данные или null если ничего не найдено
     * 
     */
    
    public function toString()
    {
        return htmlspecialchars($this->httpData);
    }

    /*
     * обрабатывает данные в свойстве $this->httpData как целое число
     * 
     * @access - public
     * @return - обработанные данные или null если ничего не найдено
     * 
     */
    
    public function toInteger()
    {
        return (int)$this->httpData;
    }
    
    /*
     * обрабатывает данные в свойстве $this->httpData как число с плавующей точкой
     * 
     * @access - public
     * @return - обработанные данные или null если ничего не найдено
     * 
     */
    
    public function toFloat()
    {
        return (float)$this->httpData;
    }

    /*
     * обрабатывает данные в свойстве $this->httpData как ссылку.
     * использовать метод только для значения глобального массива $_SERVER['REQUEST_URI']
     * получает строку БЕЗ параметров
     * 
     * @access - public
     * @return - обработанные данные или null если ничего не найдено
     * 
     */
    
    public function toUri()
    {
        // пропускаем строку через декодер урлов. чистим от пробелов и приводим у нижнему регистру
        $this->httpData  = urldecode(trim(mb_strtolower($this->httpData)));
        // бьем урл на массив по знаку вопроса
        $uri             = explode('?', $this->httpData);
        // сохраняем все что до знака вопроса
        $this->httpData  = $uri[0];
        
        // если урл равен слешу (главная страница)
        if ($this->httpData == '/')
            // возвращаем его
            return $this->httpData;
                
        // пробиваем по регулярному выражению
        if (!preg_match("/^[-_\.a-z0-9\/]+[\/]{1}$/s", $this->httpData))
            return NULL;
            
        return $this->httpData;
    }
    
    /*
     * метод принудительно вставляет значение в свойство httpData. После чего его можно обработать методами преобразования
     * 
     * @access - public
     * @return - сам себя
     *
     * @param ??? data - присланные данные
     */
    
    public function setData($data)
    {
        $this->httpData = $data;
        
        return $this;
    }
    
    /*
     * в отличие от остальных методов, просто возвращает полученные данные
     * 
     * @access - public
     * @return - данные или null если ничего не найдено
     * 
     */
    
    public function getData()
    {
        return $this->httpData;
    }
}
